# -*- coding: utf-8 -*-
from __future__ import (
    division, absolute_import, print_function, unicode_literals,
)


NAME = 'tcp_rsync'
VERSION = '0.1.rc0'
AUTHORS = [
    'huntzhan',
]
EMAILS = [
    'programmer.zhx@gmail.com',
]
LICENSE = ''
URL = ''
DESCRIPTION = (
    '1. Quick Deployment Of Rsync Daemon For TCP Transmission; '
    '2. Encapsulation For Commonly Used Operations. '
)
